@@ -3,11 +3,13 @@ context("Parallel")
 if (require("doMC", quietly = TRUE)) {
   registerDoMC(2)
 
-  test_that("l_ply respects .parallel", {
-    expect_that(
-      l_ply(c(0.1, 0.1), Sys.sleep, .parallel = TRUE),
-      takes_less_than(0.15))
-  })
+  if (identical(Sys.getenv("NOT_CRAN"), "true")) {
+    test_that("l_ply respects .parallel", {
+      expect_that(
+        l_ply(c(0.1, 0.1), Sys.sleep, .parallel = TRUE),
+        takes_less_than(0.15))
+    })
+  }
 
   test_that("l_ply + .parallel complains about invalid arguments", {
     expect_message(
